@@ -10,6 +10,7 @@
 import json
 import os
 import re
+import logging
 from glob import glob
 
 from pilot.common.errorcodes import ErrorCodes
@@ -22,9 +23,7 @@ from pilot.util.workernode import get_local_disk_space
 from .common import update_job_data, parse_jobreport_data
 from .metadata import get_metadata_from_xml, get_total_number_of_events, get_guid_from_xml
 
-import logging
 logger = logging.getLogger(__name__)
-
 errors = ErrorCodes()
 
 
@@ -53,10 +52,10 @@ def interpret(job):
 
     # check for special errors
     if exit_code == 146:
-        logger.warning('user tarball was not downloaded (payload exit code %d)' % exit_code)
+        logger.warning('user tarball was not downloaded (payload exit code %d)', exit_code)
         set_error_nousertarball(job)
     elif exit_code == 160:
-        logger.info('ignoring harmless preprocess exit code %d' % exit_code)
+        logger.info('ignoring harmless preprocess exit code %d', exit_code)
         job.transexitcode = 0
         job.exitcode = 0
         exit_code = 0
@@ -64,16 +63,16 @@ def interpret(job):
     # extract special information, e.g. number of events
     try:
         extract_special_information(job)
-    except PilotException as error:
-        logger.error('PilotException caught while extracting special job information: %s' % error)
-        exit_code = error.get_error_code()
+    except PilotException as exc:
+        logger.error('PilotException caught while extracting special job information: %s', exc)
+        exit_code = exc.get_error_code()
         job.piloterrorcodes, job.piloterrordiags = errors.add_error_code(exit_code)
 
     # interpret the exit info from the payload
     try:
         interpret_payload_exit_info(job)
-    except Exception as error:
-        logger.warning('exception caught while interpreting payload exit info: %s', error)
+    except Exception as exc:
+        logger.warning('exception caught while interpreting payload exit info: %s', exc)
 
     return exit_code
 
@@ -107,7 +106,7 @@ def interpret_payload_exit_info(job):
 
         # double check local space
         spaceleft = convert_mb_to_b(get_local_disk_space(os.getcwd()))  # B (diskspace is in MB)
-        logger.info('verifying local space: %d B' % spaceleft)
+        logger.info('verifying local space: %d B', spaceleft)
         return
 
     # look for specific errors in the stdout (full)
@@ -141,11 +140,11 @@ def is_out_of_memory(job):
     files = {stderr: ["FATAL out of memory: taking the application down"], stdout: ["St9bad_alloc", "std::bad_alloc"]}
     for path in files:
         if os.path.exists(path):
-            logger.info('looking for out-of-memory errors in %s' % os.path.basename(path))
+            logger.info('looking for out-of-memory errors in %s', os.path.basename(path))
             if os.path.getsize(path) > 0:
                 matched_lines = grep(files[path], path)
-                if len(matched_lines) > 0:
-                    logger.warning("identified an out of memory error in %s %s:" % (job.payload, os.path.basename(path)))
+                if matched_lines:
+                    logger.warning("identified an out of memory error in %s %s:", job.payload, os.path.basename(path))
                     for line in matched_lines:
                         logger.info(line)
                     out_of_memory = True
@@ -198,10 +197,7 @@ def is_installation_error(job):
     stdout = os.path.join(job.workdir, config.Payload.payloadstdout)
     _tail = tail(stdout)
     res_tmp = _tail[:1024]
-    if res_tmp[0:3] == "sh:" and 'setup.sh' in res_tmp and 'No such file or directory' in res_tmp:
-        return True
-    else:
-        return False
+    return res_tmp[0:3] == "sh:" and 'setup.sh' in res_tmp and 'No such file or directory' in res_tmp
 
 
 def is_atlassetup_error(job):
@@ -215,11 +211,7 @@ def is_atlassetup_error(job):
     stdout = os.path.join(job.workdir, config.Payload.payloadstdout)
     _tail = tail(stdout)
     res_tmp = _tail[:2048]
-    if "AtlasSetup(FATAL): Fatal exception" in res_tmp:
-        logger.warning('AtlasSetup FATAL failure detected')
-        return True
-    else:
-        return False
+    return "AtlasSetup(FATAL): Fatal exception" in res_tmp
 
 
 def is_nfssqlite_locking_problem(job):
@@ -252,8 +244,8 @@ def extract_special_information(job):
     # get the DB info from the jobReport
     try:
         find_db_info(job)
-    except Exception as e:
-        logger.warning('detected problem with parsing job report (in find_db_info()): %s' % e)
+    except Exception as exc:
+        logger.warning('detected problem with parsing job report (in find_db_info()): %s', exc)
 
 
 def find_number_of_events(job):
@@ -265,29 +257,29 @@ def find_number_of_events(job):
     """
 
     if job.nevents:
-        logger.info('number of events already known: %d' % job.nevents)
+        logger.info('number of events already known: %d', job.nevents)
         return
 
     logger.info('looking for number of processed events (source #1: jobReport.json)')
     find_number_of_events_in_jobreport(job)
     if job.nevents > 0:
-        logger.info('found %d processed events' % job.nevents)
+        logger.info('found %d processed events', job.nevents)
         return
 
     logger.info('looking for number of processed events (source #2: metadata.xml)')
     find_number_of_events_in_xml(job)
     if job.nevents > 0:
-        logger.info('found %d processed events' % job.nevents)
+        logger.info('found %d processed events', job.nevents)
         return
 
     logger.info('looking for number of processed events (source #3: athena summary file(s)')
-    n1, n2 = process_athena_summary(job)
-    if n1 > 0:
-        job.nevents = n1
-        logger.info('found %d processed (read) events' % job.nevents)
-    if n2 > 0:
-        job.neventsw = n2
-        logger.info('found %d processed (written) events' % job.neventsw)
+    nev1, nev2 = process_athena_summary(job)
+    if nev1 > 0:
+        job.nevents = nev1
+        logger.info('found %d processed (read) events', job.nevents)
+    if nev2 > 0:
+        job.neventsw = nev2
+        logger.info('found %d processed (written) events', job.neventsw)
 
 
 def find_number_of_events_in_jobreport(job):
@@ -300,8 +292,8 @@ def find_number_of_events_in_jobreport(job):
 
     try:
         work_attributes = parse_jobreport_data(job.metadata)
-    except Exception as e:
-        logger.warning('exception caught while parsing job report: %s' % e)
+    except Exception as exc:
+        logger.warning('exception caught while parsing job report: %s', exc)
         return
 
     if 'nEvents' in work_attributes:
@@ -309,8 +301,8 @@ def find_number_of_events_in_jobreport(job):
             n_events = work_attributes.get('nEvents')
             if n_events:
                 job.nevents = int(n_events)
-        except ValueError as e:
-            logger.warning('failed to convert number of events to int: %s' % e)
+        except ValueError as exc:
+            logger.warning('failed to convert number of events to int: %s', exc)
 
 
 def find_number_of_events_in_xml(job):
@@ -324,8 +316,8 @@ def find_number_of_events_in_xml(job):
 
     try:
         metadata = get_metadata_from_xml(job.workdir)
-    except Exception as e:
-        msg = "Exception caught while interpreting XML: %s" % e
+    except Exception as exc:
+        msg = "Exception caught while interpreting XML: %s" % exc
         raise BadXML(msg)
 
     if metadata:
@@ -342,8 +334,8 @@ def process_athena_summary(job):
     :return: number of read events (int), number of written events (int).
     """
 
-    n1 = 0
-    n2 = 0
+    nev1 = 0
+    nev2 = 0
     file_pattern_list = ['AthSummary*', 'AthenaSummary*']
 
     file_list = []
@@ -362,20 +354,20 @@ def process_athena_summary(job):
         recent_summary_file, recent_time, oldest_summary_file, oldest_time = \
             find_most_recent_and_oldest_summary_files(file_list)
         if oldest_summary_file == recent_summary_file:
-            logger.info("summary file %s will be processed for errors and number of events" %
+            logger.info("summary file %s will be processed for errors and number of events",
                         os.path.basename(oldest_summary_file))
         else:
-            logger.info("most recent summary file %s (updated at %d) will be processed for errors [to be implemented]" %
-                        (os.path.basename(recent_summary_file), recent_time))
-            logger.info("oldest summary file %s (updated at %d) will be processed for number of events" %
-                        (os.path.basename(oldest_summary_file), oldest_time))
+            logger.info("most recent summary file %s (updated at %d) will be processed for errors [to be implemented]",
+                        os.path.basename(recent_summary_file), recent_time)
+            logger.info("oldest summary file %s (updated at %d) will be processed for number of events",
+                        os.path.basename(oldest_summary_file), oldest_time)
 
         # Get the number of events from the oldest summary file
-        n1, n2 = get_number_of_events_from_summary_file(oldest_summary_file)
-        logger.info("number of events: %d (read)" % n1)
-        logger.info("number of events: %d (written)" % n2)
+        nev1, nev2 = get_number_of_events_from_summary_file(oldest_summary_file)
+        logger.info("number of events: %d (read)", nev1)
+        logger.info("number of events: %d (written)", nev2)
 
-    return n1, n2
+    return nev1, nev2
 
 
 def find_most_recent_and_oldest_summary_files(file_list):
@@ -394,8 +386,8 @@ def find_most_recent_and_oldest_summary_files(file_list):
             # get the modification time
             try:
                 st_mtime = os.path.getmtime(summary_file)
-            except Exception as e:  # Python 2/3
-                logger.warning("could not read modification time of file %s: %s" % (summary_file, e))
+            except OSError as exc:  # Python 2/3
+                logger.warning("could not read modification time of file %s: %s", summary_file, exc)
             else:
                 if st_mtime > recent_time:
                     recent_time = st_mtime
@@ -406,8 +398,12 @@ def find_most_recent_and_oldest_summary_files(file_list):
     else:
         oldest_summary_file = file_list[0]
         recent_summary_file = oldest_summary_file
-        oldest_time = os.path.getmtime(oldest_summary_file)
-        recent_time = oldest_time
+        try:
+            oldest_time = os.path.getmtime(oldest_summary_file)
+        except OSError as exc:  # Python 2/3
+            logger.warning("could not read modification time of file %s: %s", oldest_summary_file, exc)
+        else:
+            recent_time = oldest_time
 
     return recent_summary_file, recent_time, oldest_summary_file, oldest_time
 
@@ -420,27 +416,27 @@ def get_number_of_events_from_summary_file(oldest_summary_file):
     :return: number of read events (int), number of written events (int).
     """
 
-    n1 = 0
-    n2 = 0
+    nev1 = 0
+    nev2 = 0
 
-    f = open_file(oldest_summary_file, 'r')
-    if f:
-        lines = f.readlines()
-        f.close()
+    _file = open_file(oldest_summary_file, 'r')
+    if _file:
+        lines = _file.readlines()
+        _file.close()
 
-        if len(lines) > 0:
+        if lines:
             for line in lines:
                 if "Events Read:" in line:
                     try:
-                        n1 = int(re.match(r'Events Read\: *(\d+)', line).group(1))  # Python 3 (added r)
-                    except ValueError as e:
-                        logger.warning('failed to convert number of read events to int: %s' % e)
+                        nev1 = int(re.match(r'Events Read\: *(\d+)', line).group(1))  # Python 3 (added r)
+                    except ValueError as exc:
+                        logger.warning('failed to convert number of read events to int: %s', exc)
                 if "Events Written:" in line:
                     try:
-                        n2 = int(re.match(r'Events Written\: *(\d+)', line).group(1))  # Python 3 (added r)
-                    except ValueError as e:
-                        logger.warning('failed to convert number of written events to int: %s' % e)
-                if n1 > 0 and n2 > 0:
+                        nev2 = int(re.match(r'Events Written\: *(\d+)', line).group(1))  # Python 3 (added r)
+                    except ValueError as exc:
+                        logger.warning('failed to convert number of written events to int: %s', exc)
+                if nev1 > 0 and nev2 > 0:
                     break
         else:
             logger.warning('failed to get number of events from empty summary file')
@@ -448,7 +444,7 @@ def get_number_of_events_from_summary_file(oldest_summary_file):
     # Get the errors from the most recent summary file
     # ...
 
-    return n1, n2
+    return nev1, nev2
 
 
 def find_db_info(job):
@@ -463,15 +459,15 @@ def find_db_info(job):
     if '__db_time' in work_attributes:
         try:
             job.dbtime = int(work_attributes.get('__db_time'))
-        except ValueError as e:
-            logger.warning('failed to convert dbtime to int: %s' % e)
-        logger.info('dbtime (total): %d' % job.dbtime)
+        except ValueError as exc:
+            logger.warning('failed to convert dbtime to int: %s', exc)
+        logger.info('dbtime (total): %d', job.dbtime)
     if '__db_data' in work_attributes:
         try:
             job.dbdata = work_attributes.get('__db_data')
-        except ValueError as e:
-            logger.warning('failed to convert dbdata to int: %s' % e)
-        logger.info('dbdata (total): %d' % job.dbdata)
+        except ValueError as exc:
+            logger.warning('failed to convert dbdata to int: %s', exc)
+        logger.info('dbdata (total): %d', job.dbdata)
 
 
 def set_error_nousertarball(job):
@@ -508,7 +504,7 @@ def extract_tarball_url(_tail):
     if "https://" in _tail or "http://" in _tail:
         pattern = r"(https?\:\/\/.+)"
         found = re.findall(pattern, _tail)
-        if len(found) > 0:
+        if found:
             tarball_url = found[0]
 
     return tarball_url
@@ -541,15 +537,15 @@ def process_metadata_from_xml(job):
             metadata = None
             try:
                 metadata = get_metadata_from_xml(job.workdir)
-            except Exception as e:
-                msg = "Exception caught while interpreting XML: %s (ignoring it, but guids must now be generated)" % e
+            except Exception as exc:
+                msg = "Exception caught while interpreting XML: %s (ignoring it, but guids must now be generated)" % exc
                 logger.warning(msg)
             if metadata:
                 dat.guid = get_guid_from_xml(metadata, dat.lfn)
-                logger.info('read guid for lfn=%s from xml: %s' % (dat.lfn, dat.guid))
+                logger.info('read guid for lfn=%s from xml: %s', dat.lfn, dat.guid)
             else:
                 dat.guid = get_guid()
-                logger.info('generated guid for lfn=%s: %s' % (dat.lfn, dat.guid))
+                logger.info('generated guid for lfn=%s: %s', dat.lfn, dat.guid)
 
 
 def process_job_report(job):
@@ -567,7 +563,7 @@ def process_job_report(job):
     # get the job report
     path = os.path.join(job.workdir, config.Payload.jobreport)
     if not os.path.exists(path):
-        logger.warning('job report does not exist: %s' % path)
+        logger.warning('job report does not exist: %s', path)
 
         # get the metadata from the xml file instead, which must exist for most production transforms
         process_metadata_from_xml(job)
@@ -583,16 +579,16 @@ def process_job_report(job):
             # compulsory fields
             try:
                 job.exitcode = job.metadata['exitCode']
-            except Exception as e:
-                logger.warning('could not find compulsory payload exitCode in job report: %s (will be set to 0)' % e)
+            except KeyError as exc:
+                logger.warning('could not find compulsory payload exitCode in job report: %s (will be set to 0)', exc)
                 job.exitcode = 0
             else:
-                logger.info('extracted exit code from job report: %d' % job.exitcode)
+                logger.info('extracted exit code from job report: %d', job.exitcode)
             try:
                 job.exitmsg = job.metadata['exitMsg']
-            except Exception as e:
+            except KeyError as exc:
                 logger.warning('could not find compulsory payload exitMsg in job report: %s '
-                               '(will be set to empty string)' % e)
+                               '(will be set to empty string)', exc)
                 job.exitmsg = ""
             else:
                 # assign special payload error code
@@ -604,7 +600,7 @@ def process_job_report(job):
                     job.piloterrorcode = errors.PAYLOADSIGSEGV
                     job.piloterrordiag = diagnostics
                 else:
-                    logger.info('extracted exit message from job report: %s' % job.exitmsg)
+                    logger.info('extracted exit message from job report: %s', job.exitmsg)
                     if job.exitmsg != 'OK':
                         job.exeerrordiag = job.exitmsg
                         job.exeerrorcode = job.exitcode
@@ -632,21 +628,21 @@ def get_job_report_errors(job_report_dictionary):
 
     job_report_errors = []
     if 'reportVersion' in job_report_dictionary:
-        logger.info("scanning jobReport (v %s) for error info" % job_report_dictionary.get('reportVersion'))
+        logger.info("scanning jobReport (v %s) for error info", job_report_dictionary.get('reportVersion'))
     else:
         logger.warning("jobReport does not have the reportVersion key")
 
     if 'executor' in job_report_dictionary:
         try:
             error_details = job_report_dictionary['executor'][0]['logfileReport']['details']['ERROR']
-        except Exception as e:
-            logger.warning("WARNING: aborting jobReport scan: %s" % e)
+        except (KeyError, TypeError, IndexError) as exc:
+            logger.warning("WARNING: aborting jobReport scan: %s", exc)
         else:
-            try:
-                for m in error_details:
-                    job_report_errors.append(m['message'])
-            except Exception as e:
-                logger.warning("did not get a list object: %s" % e)
+            if isinstance(error_details, list):
+                for msg in error_details:
+                    job_report_errors.append(msg['message'])
+            else:
+                logger.warning("did not get a list object: %s", type(error_details))
     else:
         logger.warning("jobReport does not have the executor key (aborting)")
 
@@ -663,11 +659,11 @@ def is_bad_alloc(job_report_errors):
 
     bad_alloc = False
     diagnostics = ""
-    for m in job_report_errors:
-        if "bad_alloc" in m:
-            logger.warning("encountered a bad_alloc error: %s" % m)
+    for err in job_report_errors:
+        if "bad_alloc" in err:
+            logger.warning("encountered a bad_alloc error: %s", err)
             bad_alloc = True
-            diagnostics = m
+            diagnostics = err
             break
 
     return bad_alloc, diagnostics
@@ -692,7 +688,7 @@ def get_log_extracts(job, state):
     # for failed/holding jobs, add extracts from the pilot log file, but always add it to the pilot log itself
     _extracts = get_pilot_log_extracts(job)
     if _extracts != "":
-        logger.warning('detected the following tail of warning/fatal messages in the pilot log:\n%s' % _extracts)
+        logger.warning('detected the following tail of warning/fatal messages in the pilot log:\n%s', _extracts)
         if state == 'failed' or state == 'holding':
             extracts += _extracts
 
@@ -723,9 +719,9 @@ def get_panda_tracer_log(job):
             extracts += message
             logger.warning(message)
         else:
-            logger.info("PanDA tracer log (%s) has zero size (no outbound connections detected)" % tracerlog)
+            logger.info("PanDA tracer log (%s) has zero size (no outbound connections detected)", tracerlog)
     else:
-        logger.debug("PanDA tracer log does not exist: %s (ignoring)" % tracerlog)
+        logger.debug("PanDA tracer log does not exist: %s (ignoring)", tracerlog)
 
     return extracts
 
@@ -755,7 +751,7 @@ def get_pilot_log_extracts(job):
         #matched_lines = grep(errormsgs, path)
         #_extracts = ""
         #if len(matched_lines) > 0:
-        #    logger.debug("dumping warning messages from %s:\n" % os.path.basename(path))
+        #    logger.debug("dumping warning messages from %s:\n", os.path.basename(path))
         #    for line in matched_lines:
         #        _extracts += line + "\n"
         #if _extracts != "":
@@ -765,6 +761,6 @@ def get_pilot_log_extracts(job):
         #    extracts += "\n- Error messages from %s -\n" % config.Pilot.pilotlog
         #    extracts += _extracts
     else:
-        logger.warning('pilot log file does not exist: %s' % path)
+        logger.warning('pilot log file does not exist: %s', path)
 
     return extracts
